@@ -21,5 +21,5 @@ R_init_disjo(DllInfo *dll)
 {
     R_registerRoutines(dll, NULL, R_CallDef, NULL, NULL);
     R_useDynamicSymbols(dll, FALSE);
-    R_forceSymbols(dll, TRUE);
+    R_forceSymbols(dll, FALSE);
 }
